@@ -23,10 +23,12 @@ def setup_vectra_module():
     cyjax_api_key = input('Please provide the Cyjax API key:')
     vectra_fqdn = input('Please provide the Vectra FQDN:')
     vectra_api_key = input('Please provide the Vectra API key:')
-    vectra_threat_feed_id = input('Please provide the Vectra Threat feed ID:')
+    vectra_daily_threat_feed_id = input('Please provide the Vectra Threat feed ID for daily indicators:')
+    vectra_weekly_threat_feed_id = input('Please provide the Vectra Threat feed ID for weekly indicators:')
 
     try:
-        configuration.set_config(cyjax_api_key, vectra_fqdn, vectra_api_key, vectra_threat_feed_id)
+        configuration.set_config(cyjax_api_key, vectra_fqdn, vectra_api_key, vectra_daily_threat_feed_id,
+                                 vectra_weekly_threat_feed_id)
         print("Configuration saved to %s" % (configuration.get_config_file_path()))
     except InvalidConfigurationException as exception:
         print('Error: {}'.format(str(exception)))
