@@ -14,7 +14,8 @@ from src.vectra_client import VectraClient
 
 CYJAX_API_KEY = 'cyjax_api'
 VECTRA_FQDN = 'vectra_fqdn'
-VECTRA_THREAT_FEED_ID = 'vectra_theat_feed_id'
+VECTRA_DAILY_THREAT_FEED_ID = 'vectra_daily_threat_feed_id'
+VECTRA_WEEKLY_THREAT_FEED_ID = 'vectra_weekly_threat_feed_id'
 VECTRA_API_KEY = 'vectra_api_key'
 VECTRA_SSL_VERIFICATION = 'vectra_ssl_verification'
 LAST_SYNC_TIMESTAMP = 'last_sync_timestamp'
@@ -32,6 +33,7 @@ class Configuration:
     def __init__(self):
         """Class constructor."""
         self.config = {}
+        self.config_path = None
         self.config_file_path = None
 
     def load(self):
@@ -39,24 +41,45 @@ class Configuration:
         # Find config path
         if platform.mac_ver()[0] != '':
             # macOS
-            config_path = os.path.join(os.environ['HOME'], 'Library/Preferences')
+            self.config_path = os.path.join(os.environ['HOME'], 'Library/Preferences')
         else:
             # XDG-compatible
-            config_path = os.environ.get('XDG_CONFIG_HOME', os.path.join(os.environ['HOME'], '.config'))
-            if not os.path.exists(config_path):
-                os.mkdir(config_path)
-        self.config_file_path = config_path + '/' + CONFIG_FILE_PATH
+            self.config_path = os.environ.get('XDG_CONFIG_HOME', os.path.join(os.environ['HOME'], '.config'))
+            if not os.path.exists(self.config_path):
+                os.mkdir(self.config_path)
+        self.config_file_path = self.config_path + '/' + CONFIG_FILE_PATH
         if os.path.isfile(self.config_file_path):
             with open(self.config_file_path, 'r') as json_file:
                 self.config = json.load(json_file)
 
+    def get_config_path(self) -> str:
+        """
+        Returns the configuration path.
+        :return: The configuration path
+        """
+        return self.config_path
+
     def get_config_file_path(self) -> str:
         """
         Returns the configuration file path.
-        :return: The  configuration file path
+        :return: The configuration file path
         """
         return self.config_file_path
 
+    def get_daily_stix_file_path(self) -> str:
+        """
+        Returns the daily STIX file path.
+        :return: The daily STIX file path.
+        """
+        return self.get_config_path() + '/stix-' + datetime.now().strftime("%Y%m%d") + '.xml'
+
+    def get_weekly_stix_file_path(self) -> str:
+        """
+        Returns the weekly STIX file path.
+        :return: The weekly STIX file path.
+        """
+        return self.get_config_path() + '/stix-' + datetime.now().strftime("%Y%W") + '.xml'
+
     def get_cyjax_api_key(self) -> Union[str, None]:
         """
         Returns the Cyjax API key.
@@ -78,12 +101,12 @@ class Configuration:
         """
         return self._get_config(VECTRA_API_KEY)
 
-    def get_vectra_threat_feed_id(self) -> Union[str, None]:
+    def get_vectra_threat_feed_ids(self):
         """
-        Returns the Vectra threat feed ID.
-        :return: The Vectra threat feed ID.
+        Returns the Vectra threat feed IDs.
+        :return: The Vectra threat feed IDs.
         """
-        return self._get_config(VECTRA_THREAT_FEED_ID)
+        return self._get_config(VECTRA_DAILY_THREAT_FEED_ID), self._get_config(VECTRA_WEEKLY_THREAT_FEED_ID)
 
     def get_vectra_ssl_verification(self) -> Union[bool, None]:
         """
@@ -107,25 +130,29 @@ class Configuration:
         self.config[LAST_SYNC_TIMESTAMP] = last_sync_timestamp.replace(microsecond=0).isoformat()
         self._save_config()
 
-    def set_config(self, cyjax_api_key: str, vectra_fqdn: str, vectra_api_key: str, vectra_threat_feed_id: str):
+    # pylint: disable=too-many-arguments
+    def set_config(self, cyjax_api_key: str, vectra_fqdn: str, vectra_api_key: str, vectra_daily_threat_feed_id: str,
+                   vectra_weekly_threat_feed_id: str):
         """
         Validates and saves the configuration.
         :param cyjax_api_key: The Cyjax API key.
         :param vectra_fqdn: The Vectra FQDN.
         :param vectra_api_key: The Vectra API key.
-        :param vectra_threat_feed_id: The Vectra threat feed ID.
+        :param vectra_daily_threat_feed_id: The Vectra threat daily feed ID.
+        :param vectra_weekly_threat_feed_id: The Vectra threat weekly feed ID.
         """
         self.config[CYJAX_API_KEY] = cyjax_api_key
         self.config[VECTRA_FQDN] = vectra_fqdn
         self.config[VECTRA_API_KEY] = vectra_api_key
-        self.config[VECTRA_THREAT_FEED_ID] = vectra_threat_feed_id
+        self.config[VECTRA_DAILY_THREAT_FEED_ID] = vectra_daily_threat_feed_id
+        self.config[VECTRA_WEEKLY_THREAT_FEED_ID] = vectra_weekly_threat_feed_id
 
         self.validate()
 
         # Validate Vectra
         try:
             vectra_client = VectraClient(self.config[VECTRA_FQDN], self.config[VECTRA_API_KEY],
-                                         self.config[VECTRA_THREAT_FEED_ID], False)
+                                         self.get_vectra_threat_feed_ids(), False)
             vectra_response = vectra_client.health()
 
             if vectra_response.status_code != 200:
@@ -161,15 +188,18 @@ class Configuration:
         if VECTRA_API_KEY not in self.config or not self.config[VECTRA_API_KEY]:
             raise InvalidConfigurationException('The Vectra API key cannot be empty.')
 
-        if VECTRA_THREAT_FEED_ID not in self.config or not self.config[VECTRA_THREAT_FEED_ID]:
-            raise InvalidConfigurationException('The Vectra threat feed ID cannot be empty.')
+        if VECTRA_DAILY_THREAT_FEED_ID not in self.config or not self.config[VECTRA_DAILY_THREAT_FEED_ID]:
+            raise InvalidConfigurationException('The Vectra daily threat feed ID cannot be empty.')
+
+        if VECTRA_WEEKLY_THREAT_FEED_ID not in self.config or not self.config[VECTRA_WEEKLY_THREAT_FEED_ID]:
+            raise InvalidConfigurationException('The Vectra weekly threat feed ID cannot be empty.')
 
     def _get_config(self, config_key, default_value=None):
         """
-
-        :param config_key:
-        :param default_value:
-        :return:
+        Returns a configuration value.
+        :param config_key: The key.
+        :param default_value: The default value if not found.
+        :return: The configuration value.
         """
         return self.config[config_key] if config_key in self.config else default_value
 
